@@ -1,7 +1,7 @@
 from typing import Iterable, List, TYPE_CHECKING
 
 # from .console import Console as BaseConsole
-from .__init__ import get_console
+from . import get_console
 from .segment import Segment
 from .terminal_theme import DEFAULT_TERMINAL_THEME
 
@@ -20,7 +20,7 @@ class JupyterRenderable:
         self.html = html
 
     @classmethod
-    def render(self, rich_renderable: "RenderableType") -> str:
+    def render(cls, rich_renderable: "RenderableType") -> str:
         console = get_console()
         segments = console.render(rich_renderable, console.options)
         html = _render_segments(segments)
