@@ -1,14 +1,17 @@
 from __future__ import absolute_import
 
+import os.path
 import platform
 import sys
 from dataclasses import dataclass, field
+from textwrap import indent
 from traceback import walk_tb
 from types import TracebackType
 from typing import Callable, Dict, List, Optional, Type
 
 from pygments.lexers import guess_lexer_for_filename
 from pygments.token import (
+    Comment,
     Keyword,
     Name,
     Number,
@@ -39,6 +42,9 @@ from .theme import Theme
 
 WINDOWS = platform.system() == "Windows"
 
+LOCALS_MAX_LENGTH = 10
+LOCALS_MAX_STRING = 80
+
 
 def install(
     *,
@@ -48,6 +54,7 @@ def install(
     theme: Optional[str] = None,
     word_wrap: bool = False,
     show_locals: bool = False,
+    indent_guides: bool = True,
 ) -> Callable:
     """Install a rich traceback handler.
 
@@ -62,6 +69,7 @@ def install(
             a theme appropriate for the platform.
         word_wrap (bool, optional): Enable word wrapping of long lines. Defaults to False.
         show_locals (bool, optional): Enable display of local variables. Defaults to False.
+        indent_guides (bool, optional): Enable indent guides in code and locals. Defaults to True.
 
     Returns:
         Callable: The previous exception handler that was replaced.
@@ -84,6 +92,7 @@ def install(
                 theme=theme,
                 word_wrap=word_wrap,
                 show_locals=show_locals,
+                indent_guides=indent_guides,
             )
         )
 
@@ -138,6 +147,10 @@ class Traceback:
         theme (str, optional): Override pygments theme used in traceback.
         word_wrap (bool, optional): Enable word wrapping of long lines. Defaults to False.
         show_locals (bool, optional): Enable display of local variables. Defaults to False.
+        indent_guides (bool, optional): Enable indent guides in code and locals. Defaults to True.
+        locals_max_length (int, optional): Maximum length of containers before abbreviating, or None for no abbreviation.
+            Defaults to 10.
+        locals_max_string (int, optional): Maximum length of string before truncating, or None to disable. Defaults to 80.
     """
 
     def __init__(
@@ -148,6 +161,9 @@ class Traceback:
         theme: Optional[str] = None,
         word_wrap: bool = False,
         show_locals: bool = False,
+        indent_guides: bool = True,
+        locals_max_length: int = LOCALS_MAX_LENGTH,
+        locals_max_string: int = LOCALS_MAX_STRING,
     ):
         if trace is None:
             exc_type, exc_value, traceback = sys.exc_info()
@@ -164,6 +180,9 @@ class Traceback:
         self.theme = Syntax.get_theme(theme or "ansi_dark")
         self.word_wrap = word_wrap
         self.show_locals = show_locals
+        self.indent_guides = indent_guides
+        self.locals_max_length = locals_max_length
+        self.locals_max_string = locals_max_string
 
     @classmethod
     def from_exception(
@@ -176,6 +195,9 @@ class Traceback:
         theme: Optional[str] = None,
         word_wrap: bool = False,
         show_locals: bool = False,
+        indent_guides: bool = True,
+        locals_max_length: int = LOCALS_MAX_LENGTH,
+        locals_max_string: int = LOCALS_MAX_STRING,
     ) -> "Traceback":
         """Create a traceback from exception info
 
@@ -188,11 +210,17 @@ class Traceback:
             theme (str, optional): Override pygments theme used in traceback.
             word_wrap (bool, optional): Enable word wrapping of long lines. Defaults to False.
             show_locals (bool, optional): Enable display of local variables. Defaults to False.
+            indent_guides (bool, optional): Enable indent guides in code and locals. Defaults to True.
+            locals_max_length (int, optional): Maximum length of containers before abbreviating, or None for no abbreviation.
+                Defaults to 10.
+            locals_max_string (int, optional): Maximum length of string before truncating, or None to disable. Defaults to 80.
 
         Returns:
             Traceback: A Traceback instance that may be printed.
         """
-        rich_traceback = cls.extract(exc_type, exc_value, traceback)
+        rich_traceback = cls.extract(
+            exc_type, exc_value, traceback, show_locals=show_locals
+        )
         return Traceback(
             rich_traceback,
             width=width,
@@ -200,6 +228,9 @@ class Traceback:
             theme=theme,
             word_wrap=word_wrap,
             show_locals=show_locals,
+            indent_guides=indent_guides,
+            locals_max_length=locals_max_length,
+            locals_max_string=locals_max_string,
         )
 
     @classmethod
@@ -209,6 +240,8 @@ class Traceback:
         exc_value: BaseException,
         traceback: Optional[TracebackType],
         show_locals: bool = False,
+        locals_max_length: int = LOCALS_MAX_LENGTH,
+        locals_max_string: int = LOCALS_MAX_STRING,
     ) -> Trace:
         """Extract traceback information.
 
@@ -217,6 +250,9 @@ class Traceback:
             exc_value (BaseException): Exception value.
             traceback (TracebackType): Python Traceback object.
             show_locals (bool, optional): Enable display of local variables. Defaults to False.
+            locals_max_length (int, optional): Maximum length of containers before abbreviating, or None for no abbreviation.
+                Defaults to 10.
+            locals_max_string (int, optional): Maximum length of string before truncating, or None to disable. Defaults to 80.
 
         Returns:
             Trace: A Trace instance which you can use to construct a `Traceback`.
@@ -239,12 +275,18 @@ class Traceback:
             append = stack.frames.append
 
             for frame_summary, line_no in walk_tb(traceback):
+                filename = frame_summary.f_code.co_filename
+                filename = os.path.abspath(filename) if filename else "?"
                 frame = Frame(
-                    filename=frame_summary.f_code.co_filename or "?",
+                    filename=filename,
                     lineno=line_no,
                     name=frame_summary.f_code.co_name,
                     locals={
-                        key: pretty.traverse(value)
+                        key: pretty.traverse(
+                            value,
+                            max_length=locals_max_length,
+                            max_string=locals_max_string,
+                        )
                         for key, value in frame_summary.f_locals.items()
                     }
                     if show_locals
@@ -279,6 +321,7 @@ class Traceback:
                 "pygments.string": token_style(String),
                 "pygments.function": token_style(Name.Function),
                 "pygments.number": token_style(Number),
+                "repr.indent": token_style(Comment) + Style(dim=True),
                 "repr.str": token_style(String),
                 "repr.brace": token_style(TextToken) + Style(bold=True),
                 "repr.number": token_style(Number),
@@ -300,7 +343,7 @@ class Traceback:
                     title="[traceback.title]Traceback [dim](most recent call last)",
                     style=background_style,
                     border_style="traceback.border.syntax_error",
-                    expand=False,
+                    expand=True,
                     padding=(0, 1),
                 )
                 stack_renderable = Constrain(stack_renderable, self.width)
@@ -313,8 +356,9 @@ class Traceback:
                             self._render_syntax_error(stack.syntax_error),
                             style=background_style,
                             border_style="traceback.border",
-                            expand=False,
+                            expand=True,
                             padding=(0, 1),
+                            width=self.width,
                         ),
                         self.width,
                     )
@@ -407,6 +451,7 @@ class Traceback:
                     highlight_lines={frame.lineno},
                     word_wrap=self.word_wrap,
                     code_width=88,
+                    indent_guides=self.indent_guides,
                 )
                 yield ""
             except Exception:
@@ -416,7 +461,13 @@ class Traceback:
                     Columns(
                         [
                             syntax,
-                            render_scope(frame.locals, title="locals"),
+                            render_scope(
+                                frame.locals,
+                                title="locals",
+                                indent_guides=self.indent_guides,
+                                max_length=self.locals_max_length,
+                                max_string=self.locals_max_string,
+                            ),
                         ],
                         padding=1,
                     )
@@ -437,6 +488,7 @@ if __name__ == "__main__":  # pragma: no cover
         print(one / a)
 
     def foo(a):
+
         zed = {
             "characters": {
                 "Paul Atriedies",
